From: Neeraj Kumar <s.neeraj@samsung.com>
To: dan.j.williams@intel.com, dave@stgolabs.net,
jonathan.cameron@huawei.com, dave.jiang@intel.com,
alison.schofield@intel.com, vishal.l.verma@intel.com,
ira.weiny@intel.com
Cc: a.manzanares@samsung.com, nifan.cxl@gmail.com,
anisa.su@samsung.com, vishak.g@samsung.com,
krish.reddy@samsung.com, arun.george@samsung.com,
alok.rathore@samsung.com, s.neeraj@samsung.com,
neeraj.kernel@gmail.com, linux-kernel@vger.kernel.org,
linux-cxl@vger.kernel.org, nvdimm@lists.linux.dev,
gost.dev@samsung.com, cpgs@samsung.com
Subject: [RFC PATCH 12/20] nvdimm/namespace_label: Skip region label during namespace creation
Date: Tue, 17 Jun 2025 18:09:36 +0530 [thread overview]
Message-ID: <2024918163.301750165206130.JavaMail.epsvc@epcpadp1new> (raw)
In-Reply-To: <20250617123944.78345-1-s.neeraj@samsung.com>
During namespace creation skip presence of region label if present.
Also preserve region label into labels list if present.
Signed-off-by: Neeraj Kumar <s.neeraj@samsung.com>
---
drivers/nvdimm/namespace_devs.c | 48 +++++++++++++++++++++++++++++----
1 file changed, 43 insertions(+), 5 deletions(-)
diff --git a/drivers/nvdimm/namespace_devs.c b/drivers/nvdimm/namespace_devs.c
index b081661b7aaa..ca8f8546170c 100644
--- a/drivers/nvdimm/namespace_devs.c
+++ b/drivers/nvdimm/namespace_devs.c
@@ -1976,6 +1976,10 @@ static struct device **scan_labels(struct nd_region *nd_region)
if (!nd_label)
continue;
+ /* skip region labels if present */
+ if (is_region_label(ndd, nd_label))
+ continue;
+
/* skip labels that describe extents outside of the region */
if (nsl_get_dpa(ndd, &nd_label->ns_label) < nd_mapping->start ||
nsl_get_dpa(ndd, &nd_label->ns_label) > map_end)
@@ -2014,9 +2018,29 @@ static struct device **scan_labels(struct nd_region *nd_region)
if (count == 0) {
struct nd_namespace_pmem *nspm;
+ for (i = 0; i < nd_region->ndr_mappings; i++) {
+ struct nd_label_ent *le, *e;
+ LIST_HEAD(list);
- /* Publish a zero-sized namespace for userspace to configure. */
- nd_mapping_free_labels(nd_mapping);
+ nd_mapping = &nd_region->mapping[i];
+ if (list_empty(&nd_mapping->labels))
+ continue;
+
+ list_for_each_entry_safe(le, e, &nd_mapping->labels,
+ list) {
+ struct nd_lsa_label *nd_label = le->label;
+
+ /* preserve region labels if present */
+ if (is_region_label(ndd, nd_label))
+ list_move_tail(&le->list, &list);
+ }
+
+ /* Publish a zero-sized namespace for userspace
+ * to configure.
+ */
+ nd_mapping_free_labels(nd_mapping);
+ list_splice_init(&list, &nd_mapping->labels);
+ }
nspm = kzalloc(sizeof(*nspm), GFP_KERNEL);
if (!nspm)
goto err;
@@ -2028,7 +2052,7 @@ static struct device **scan_labels(struct nd_region *nd_region)
} else if (is_memory(&nd_region->dev)) {
/* clean unselected labels */
for (i = 0; i < nd_region->ndr_mappings; i++) {
- struct list_head *l, *e;
+ struct nd_label_ent *le, *e;
LIST_HEAD(list);
int j;
@@ -2039,10 +2063,24 @@ static struct device **scan_labels(struct nd_region *nd_region)
}
j = count;
- list_for_each_safe(l, e, &nd_mapping->labels) {
+ list_for_each_entry_safe(le, e, &nd_mapping->labels,
+ list) {
+ struct nd_lsa_label *nd_label = le->label;
+
+ /* preserve region labels */
+ if (is_region_label(ndd, nd_label)) {
+ list_move_tail(&le->list, &list);
+ continue;
+ }
+
+ /* Once preserving selected ns label done
+ * break out of loop
+ */
if (!j--)
break;
- list_move_tail(l, &list);
+
+ /* preserve selected ns label */
+ list_move_tail(&le->list, &list);
}
nd_mapping_free_labels(nd_mapping);
list_splice_init(&list, &nd_mapping->labels);
--
2.34.1
next prev parent reply other threads:[~2025-06-17 13:00 UTC|newest]
Thread overview: 66+ messages / expand[flat|nested] mbox.gz Atom feed top
[not found] <CGME20250617124008epcas5p2e702f786645d44ceb1cdd980a914ce8e@epcas5p2.samsung.com>
[not found] ` <20250617123944.78345-1-s.neeraj@samsung.com>
2025-06-17 12:39 ` [RFC PATCH 01/20] nvdimm/label: Introduce NDD_CXL_LABEL flag to set cxl label format Neeraj Kumar
2025-06-20 16:40 ` Jonathan Cameron
2025-06-26 9:48 ` Neeraj Kumar
2025-07-02 18:02 ` Ira Weiny
2025-07-03 9:58 ` Neeraj Kumar
2025-07-09 22:57 ` Dave Jiang
2025-07-18 12:13 ` Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 02/20] nvdimm/label: Prep patch to accommodate cxl lsa 2.1 support Neeraj Kumar
2025-06-23 10:53 ` Jonathan Cameron
2025-06-26 9:51 ` Neeraj Kumar
2025-07-02 17:55 ` Ira Weiny
2025-07-03 10:04 ` Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 03/20] nvdimm/namespace_label: Add namespace label changes as per CXL LSA v2.1 Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 04/20] nvdimm/label: CXL labels skip the need for 'interleave-set cookie' Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 05/20] nvdimm/region_label: Add region label updation routine Neeraj Kumar
2025-06-23 9:05 ` Jonathan Cameron
2025-06-26 9:54 ` Neeraj Kumar
2025-07-17 22:53 ` Fabio M. De Francesco
2025-07-18 13:00 ` Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 06/20] nvdimm/region_label: Add region label deletion routine Neeraj Kumar
2025-06-23 9:09 ` Jonathan Cameron
2025-06-26 9:55 ` Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 07/20] nvdimm/namespace_label: Update namespace init_labels and its region_uuid Neeraj Kumar
2025-06-23 9:11 ` Jonathan Cameron
2025-06-26 9:58 ` Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 08/20] nvdimm/label: Include region label in slot validation Neeraj Kumar
2025-06-23 9:13 ` Jonathan Cameron
2025-06-26 10:00 ` Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 09/20] nvdimm/namespace_label: Skip region label during ns label DPA reservation Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 10/20] nvdimm/region_label: Preserve cxl region information from region label Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 11/20] nvdimm/region_label: Export routine to fetch region information Neeraj Kumar
2025-06-17 12:39 ` Neeraj Kumar [this message]
2025-06-23 9:17 ` [RFC PATCH 12/20] nvdimm/namespace_label: Skip region label during namespace creation Jonathan Cameron
2025-06-26 10:02 ` Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 13/20] cxl/mem: Refactor cxl pmem region auto-assembling Neeraj Kumar
2025-06-23 9:20 ` Jonathan Cameron
2025-06-26 10:03 ` Neeraj Kumar
2025-07-10 0:38 ` Dave Jiang
2025-07-18 12:30 ` Neeraj Kumar
2025-07-21 18:11 ` Dave Jiang
2025-06-17 12:39 ` [RFC PATCH 14/20] cxl/region: Add cxl pmem region creation routine for region persistency Neeraj Kumar
2025-06-23 9:43 ` Jonathan Cameron
2025-06-26 10:23 ` Neeraj Kumar
2025-07-10 15:59 ` Dave Jiang
2025-07-18 12:45 ` Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 15/20] cxl: Add a routine to find cxl root decoder on cxl bus Neeraj Kumar
2025-06-23 9:44 ` Jonathan Cameron
2025-06-26 10:38 ` Neeraj Kumar
2025-06-26 19:19 ` Alison Schofield
2025-06-27 9:03 ` Neeraj Kumar
2025-07-10 16:23 ` Dave Jiang
2025-07-18 12:48 ` Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 16/20] cxl/mem: Preserve cxl root decoder during mem probe Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 17/20] cxl/pmem: Preserve region information into nd_set Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 18/20] cxl/pmem: Add support of cxl lsa 2.1 support in cxl pmem Neeraj Kumar
2025-06-23 9:48 ` Jonathan Cameron
2025-06-26 10:41 ` Neeraj Kumar
2025-07-10 17:18 ` Dave Jiang
2025-07-18 12:51 ` Neeraj Kumar
2025-07-21 17:44 ` Dave Jiang
2025-06-17 12:39 ` [RFC PATCH 19/20] cxl/pmem_region: Prep patch to accommodate pmem_region attributes Neeraj Kumar
2025-06-23 9:53 ` Jonathan Cameron
2025-06-26 10:45 ` Neeraj Kumar
2025-06-17 12:39 ` [RFC PATCH 20/20] cxl/pmem_region: Add cxl region label updation and deletion device attributes Neeraj Kumar
2025-06-23 9:56 ` Jonathan Cameron
2025-06-26 10:48 ` Neeraj Kumar
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=2024918163.301750165206130.JavaMail.epsvc@epcpadp1new \
--to=s.neeraj@samsung.com \
--cc=a.manzanares@samsung.com \
--cc=alison.schofield@intel.com \
--cc=alok.rathore@samsung.com \
--cc=anisa.su@samsung.com \
--cc=arun.george@samsung.com \
--cc=cpgs@samsung.com \
--cc=dan.j.williams@intel.com \
--cc=dave.jiang@intel.com \
--cc=dave@stgolabs.net \
--cc=gost.dev@samsung.com \
--cc=ira.weiny@intel.com \
--cc=jonathan.cameron@huawei.com \
--cc=krish.reddy@samsung.com \
--cc=linux-cxl@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=neeraj.kernel@gmail.com \
--cc=nifan.cxl@gmail.com \
--cc=nvdimm@lists.linux.dev \
--cc=vishak.g@samsung.com \
--cc=vishal.l.verma@intel.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox